#[repr(u8)]pub enum FaultState {
Show 17 variants
Noerror = 0,
Meterfailure = 1,
Overvoltage = 2,
Undervoltage = 3,
Overcurrent = 4,
Contactwetfailure = 5,
Contactdryfailure = 6,
Groundfault = 7,
Powerloss = 8,
Powerquality = 9,
Pilotshortcircuit = 10,
Emergencystop = 11,
Evdisconnected = 12,
Wrongpowersupply = 13,
Liveneutralswap = 14,
Overtemperature = 15,
Other = 255,
}Variants
Noerror = 0
The EVSE is not in an error state.
Meterfailure = 1
The EVSE is unable to obtain electrical measurements.
Overvoltage = 2
The EVSE input voltage level is too high.
Undervoltage = 3
The EVSE input voltage level is too low.
Overcurrent = 4
The EVSE detected charging current higher than allowed by charger.
Contactwetfailure = 5
The EVSE detected voltage on charging pins when the contactor is open.
Contactdryfailure = 6
The EVSE detected absence of voltage after enabling contactor.
Groundfault = 7
The EVSE has an unbalanced current supply.
Powerloss = 8
The EVSE has detected a loss in power.
Powerquality = 9
The EVSE has detected another power quality issue (e.g. phase imbalance).
Pilotshortcircuit = 10
The EVSE pilot signal amplitude short circuited to ground.
Emergencystop = 11
The emergency stop button was pressed.
Evdisconnected = 12
The EVSE detected that the cable has been disconnected.
Wrongpowersupply = 13
The EVSE could not determine proper power supply level.
Liveneutralswap = 14
The EVSE detected Live and Neutral are swapped.
Overtemperature = 15
The EVSE internal temperature is too high.
Other = 255
Any other reason.
Implementations