#[repr(u8)]pub enum State {
Notpluggedin = 0,
Pluggedinnodemand = 1,
Pluggedindemand = 2,
Pluggedincharging = 3,
Pluggedindischarging = 4,
Sessionending = 5,
Fault = 6,
}Variants
Notpluggedin = 0
The EV is not plugged in.
Pluggedinnodemand = 1
The EV is plugged in, but not demanding current.
Pluggedindemand = 2
The EV is plugged in and is demanding current, but EVSE is not allowing current to flow.
Pluggedincharging = 3
The EV is plugged in, charging is in progress, and current is flowing
Pluggedindischarging = 4
The EV is plugged in, discharging is in progress, and current is flowing
Sessionending = 5
The EVSE is transitioning from any plugged-in state to NotPluggedIn
Fault = 6
There is a fault, further details in the FaultState attribute
Implementations