SupplyState

Enum SupplyState 

#[repr(u8)]
pub enum SupplyState { Disabled = 0, Chargingenabled = 1, Dischargingenabled = 2, Disablederror = 3, Disableddiagnostics = 4, Enabled = 5, }

Variants



Disabled = 0

The EV is not currently allowed to charge or discharge



Chargingenabled = 1

The EV is currently allowed to charge



Dischargingenabled = 2

The EV is currently allowed to discharge



Disablederror = 3

The EV is not currently allowed to charge or discharge due to an error. The error must be cleared before operation can continue.



Disableddiagnostics = 4

The EV is not currently allowed to charge or discharge due to self-diagnostics mode.



Enabled = 5

The EV is currently allowed to charge and discharge

Implementations

Source

impl SupplyState

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value