#[repr(u8)]pub enum SupplyState {
Disabled = 0,
Chargingenabled = 1,
Dischargingenabled = 2,
Disablederror = 3,
Disableddiagnostics = 4,
Enabled = 5,
}Variants
Disabled = 0
The EV is not currently allowed to charge or discharge
Chargingenabled = 1
The EV is currently allowed to charge
Dischargingenabled = 2
The EV is currently allowed to discharge
Disablederror = 3
The EV is not currently allowed to charge or discharge due to an error. The error must be cleared before operation can continue.
Disableddiagnostics = 4
The EV is not currently allowed to charge or discharge due to self-diagnostics mode.
Enabled = 5
The EV is currently allowed to charge and discharge
Implementations